==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d6/d4b/structGUISettings.js <==
var structGUISettings =
[
    [ "UserIsAllowedToChangeNewGRFs", "d6/d4b/structGUISettings.html#a4682142c8e9abeab3c26738a5856d526", null ],
    [ "advanced_vehicle_list", "d6/d4b/structGUISettings.html#a02067c22909938c3caf44f03a97c619c", null ],
    [ "ai_developer_tools", "d6/d4b/structGUISettings.html#aedcc569fb867f40807d86100ca98b75d", null ],
    [ "auto_euro", "d6/d4b/structGUISettings.html#af8f00b94062a02dbe108ac54fca2e9c2", null ],
    [ "auto_scrolling", "d6/d4b/structGUISettings.html#af3e16e2ec1fa024d8b01099659deeb12", null ],
    [ "autosave", "d6/d4b/structGUISettings.html#a62dd3632c626f7fd5318b0536473f868", null ],
    [ "autosave_on_exit", "d6/d4b/structGUISettings.html#a1757e4b8ca3b125457458f5cd6bf3ffa", null ],
    [ "autosave_on_network_disconnect", "d6/d4b/structGUISettings.html#a679f80f12d8e03e1989b37aa79624717", null ],
    [ "coloured_news_year", "d6/d4b/structGUISettings.html#ac00406cdec77670d750eb44779562150", null ],
    [ "console_backlog_length", "d6/d4b/structGUISettings.html#ae133cd309e0fc53db8c596f47098e367", null ],
    [ "console_backlog_timeout", "d6/d4b/structGUISettings.html#ad4a75a3676a8c045e1977dccebb28608", null ],
    [ "cycle_signal_types", "d6/d4b/structGUISettings.html#a63e9455fb34f1b508994b593452b5750", null ],
    [ "date_format_in_default_names", "d6/d4b/structGUISettings.html#a8626a8856fa1b11cc365821aff17790f", null ],
    [ "default_rail_type", "d6/d4b/structGUISettings.html#a6729ef97714ba6b5295e3864e1a4ee85", null ],
    [ "default_signal_type", "d6/d4b/structGUISettings.html#a7feb3f0526aaec124fcdf960ebb7c0b4", null ],
    [ "developer", "d6/d4b/structGUISettings.html#a08f934d1eb76baefecb84f949598c451", null ],
    [ "disable_unsuitable_building", "d6/d4b/structGUISettings.html#ae2542a49b47a89614c1269e2f0a63b1e", null ],
    [ "drag_signals_density", "d6/d4b/structGUISettings.html#a7e539529318f00374e2363c1bfbc9cff", null ],
    [ "drag_signals_fixed_distance", "d6/d4b/structGUISettings.html#ae77aba49ee246af20f17e6e052cf61da", null ],
    [ "enable_signal_gui", "d6/d4b/structGUISettings.html#ad8657e45f83032d9c1224e778f0594aa", null ],
    [ "errmsg_duration", "d6/d4b/structGUISettings.html#aae7ba8a64938e75825dbcf8c02974e37", null ],
    [ "expenses_layout", "d6/d4b/structGUISettings.html#a06f29bfa4f830f5c97ead1fada01dcb8", null ],
    [ "graph_line_thickness", "d6/d4b/structGUISettings.html#a2e0d88194a1b4797d60491e6964bd72a", null ],
    [ "hover_delay_ms", "d6/d4b/structGUISettings.html#a21f90aa923e99dac1cefab64ed67c65b", null ],
    [ "keep_all_autosave", "d6/d4b/structGUISettings.html#a63925d3627cd4ed21b980929c9c2395a", null ],
    [ "last_newgrf_count", "d6/d4b/structGUISettings.html#afbf528c6824373b976a87815375d49e5", null ],
    [ "link_terraform_toolbar", "d6/d4b/structGUISettings.html#afddd0226ca658d7b02fe9601c0827b4d", null ],
    [ "liveries", "d6/d4b/structGUISettings.html#a1c14ea815f79911d36f5cca2c683b021", null ],
    [ "loading_indicators", "d6/d4b/structGUISettings.html#aa9478057a4c116045d7e113e97a1b4c4", null ],
    [ "lost_vehicle_warn", "d6/d4b/structGUISettings.html#a0dd8600961bcf23ea2c1d117edca9558", null ],
    [ "max_num_autosaves", "d6/d4b/structGUISettings.html#a8af1718a1b1fc9cf932c68ea3494aefe", null ],
    [ "measure_tooltip", "d6/d4b/structGUISettings.html#a4412bd6c43ce96dd3379630bee8a950e", null ],
    [ "missing_strings_threshold", "d6/d4b/structGUISettings.html#ace5a5e01800552462bc1fef38dba8701", null ],
    [ "network_chat_box_height", "d6/d4b/structGUISettings.html#a962a0d37a0fbe0d01cd1af28115b6240", null ],
    [ "network_chat_box_width_pct", "d6/d4b/structGUISettings.html#ab12df18471fde742253676eb19a72c91", null ],
    [ "network_chat_timeout", "d6/d4b/structGUISettings.html#a335b5f12b0717178bf20bf12ea45e199", null ],
    [ "new_nonstop", "d6/d4b/structGUISettings.html#a407c886da49dcc2620b923d6b0a22267", null ],
    [ "newgrf_default_palette", "d6/d4b/structGUISettings.html#a5446aa3bb546a3a7e95a45c605089245", null ],
    [ "newgrf_developer_tools", "d6/d4b/structGUISettings.html#acd5ef5752ca38b54a08a3b44c8bbc8e2", null ],
    [ "newgrf_show_old_versions", "d6/d4b/structGUISettings.html#a09062f2103557e7d3fee67e819c4ece3", null ],
    [ "news_message_timeout", "d6/d4b/structGUISettings.html#aae3de842a821dca6d5c34252897f7735", null ],
    [ "order_review_system", "d6/d4b/structGUISettings.html#a2818d3c1565d14d8c0eec35ce0eeb23f", null ],
    [ "osk_activation", "d6/d4b/structGUISettings.html#a830eeb21c81227873bdd71df30058201", null ],
    [ "pause_on_newgame", "d6/d4b/structGUISettings.html#a75aeda92f381c00943cb79cb86b7ec9e", null ],
    [ "persistent_buildingtools", "d6/d4b/structGUISettings.html#a1e66f3809d6c65b31d39db76a1461789", null ],
    [ "population_in_label", "d6/d4b/structGUISettings.html#a36d9c9a82c0f6615474d358a87a3484e", null ],
    [ "prefer_teamchat", "d6/d4b/structGUISettings.html#aa66f8142bf06302b3236f1c21b3f0456", null ],
    [ "quick_goto", "d6/d4b/structGUISettings.html#a4d3627d051572a01964fadf497c78619", null ],
    [ "right_mouse_btn_emulation", "d6/d4b/structGUISettings.html#afcc4454d53ecaf68282983c8ebd2f25e", null ],
    [ "right_mouse_wnd_close", "d6/d4b/structGUISettings.html#a0d8f9dadd3d93c7eb61c027bb3fdf6c7", null ],
    [ "scenario_developer", "d6/d4b/structGUISettings.html#abbb77d6f5fc20d08cda75ebaf565c30d", null ],
    [ "scroll_mode", "d6/d4b/structGUISettings.html#a12e65e1884e37dc64e9e5a0c4f55513e", null ],
    [ "scrollwheel_multiplier", "d6/d4b/structGUISettings.html#afd9063dd9c6ca1b76e07dd58ef492326", null ],
    [ "scrollwheel_scrolling", "d6/d4b/structGUISettings.html#adb6733da730fa602ca7c298a0f2768e6", null ],
    [ "semaphore_build_before", "d6/d4b/structGUISettings.html#a237fb4a8bd2e7c929860a401e205323a", null ],
    [ "settings_restriction_mode", "d6/d4b/structGUISettings.html#a46580e3efdd7e19fc4d11becc535595e", null ],
    [ "sg_full_load_any", "d6/d4b/structGUISettings.html#a9438bcb839b52ae803f4a135f8003856", null ],
    [ "sg_new_nonstop", "d6/d4b/structGUISettings.html#a4243b60122d03cc0c746925c95b846ef", null ],
    [ "show_date_in_logs", "d6/d4b/structGUISettings.html#a02682a29aff6444be76befea9583d998", null ],
    [ "show_finances", "d6/d4b/structGUISettings.html#a46067f7629e679ed7860dbd4100c01d0", null ],
    [ "show_track_reservation", "d6/d4b/structGUISettings.html#ad3f6a7e911574bf31bd0bc69774d8c05", null ],
    [ "smallmap_land_colour", "d6/d4b/structGUISettings.html#a5fcc20981430a95d8211f451d788d850", null ],
    [ "smooth_scroll", "d6/d4b/structGUISettings.html#acc7b711572a38f36fdc255ee58101b2b", null ],
    [ "starting_colour", "d6/d4b/structGUISettings.html#a684c835b001038a59a98310dd2dbe02c", null ],
    [ "station_dragdrop", "d6/d4b/structGUISettings.html#a3539ae01ad6ab70eda52032b4de0a377", null ],
    [ "station_gui_group_order", "d6/d4b/structGUISettings.html#ae3f7e6dfd4109686411950a2fc9330a4", null ],
    [ "station_gui_sort_by", "d6/d4b/structGUISettings.html#a03635c4b14e6c2704e03538c883177a6", null ],
    [ "station_gui_sort_order", "d6/d4b/structGUISettings.html#a6ee3e60730b312f5f101221c7a3b3cd3", null ],
    [ "station_numtracks", "d6/d4b/structGUISettings.html#a129fbfa9e2899e2983507b20e754f987", null ],
    [ "station_platlength", "d6/d4b/structGUISettings.html#abb0190f461e1386ea6e640724b3824c0", null ],
    [ "station_show_coverage", "d6/d4b/structGUISettings.html#a8d95da504feb34858820f8d77f434ca8", null ],
    [ "statusbar_pos", "d6/d4b/structGUISettings.html#a1e8ef64db05bd4583df9ddcc3d4cd7e2", null ],
    [ "stop_location", "d6/d4b/structGUISettings.html#a2e182ef230ba6da2cd36120d1d740ad6", null ],
    [ "threaded_saves", "d6/d4b/structGUISettings.html#aecb8c40b18ab5796a51fb51ed5e7fe9f", null ],
    [ "timetable_arrival_departure", "d6/d4b/structGUISettings.html#abe3768b96d2684d361da909b87321c2d", null ],
    [ "timetable_in_ticks", "d6/d4b/structGUISettings.html#a671c585d6d0b62570d204fbe1fdad191", null ],
    [ "toolbar_pos", "d6/d4b/structGUISettings.html#aad97d9b590b61269c2c3364a48db37b9", null ],
    [ "vehicle_income_warn", "d6/d4b/structGUISettings.html#a92f6e672b23f6cb9c09cf82f2a658a43", null ],
    [ "window_snap_radius", "d6/d4b/structGUISettings.html#a40c492f7f2a23d39e4dd0a610c731e8a", null ],
    [ "window_soft_limit", "d6/d4b/structGUISettings.html#a7285321bd08a820bd3cd014636d0e83c", null ],
    [ "zoom_max", "d6/d4b/structGUISettings.html#a47ffa6881883994e3f93227144e8e9a0", null ],
    [ "zoom_min", "d6/d4b/structGUISettings.html#a093fb2eac1297d51d2a71a5a255f71cc", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d6/d4b/structGUISettings.js <==
var structGUISettings =
[
    [ "UserIsAllowedToChangeNewGRFs", "d6/d4b/structGUISettings.html#a4682142c8e9abeab3c26738a5856d526", null ],
    [ "advanced_vehicle_list", "d6/d4b/structGUISettings.html#a02067c22909938c3caf44f03a97c619c", null ],
    [ "ai_developer_tools", "d6/d4b/structGUISettings.html#aedcc569fb867f40807d86100ca98b75d", null ],
    [ "auto_euro", "d6/d4b/structGUISettings.html#af8f00b94062a02dbe108ac54fca2e9c2", null ],
    [ "auto_remove_signals", "d6/d4b/structGUISettings.html#a30bda569971758afeab60d8353de0ee4", null ],
    [ "auto_scrolling", "d6/d4b/structGUISettings.html#af3e16e2ec1fa024d8b01099659deeb12", null ],
    [ "autosave", "d6/d4b/structGUISettings.html#a62dd3632c626f7fd5318b0536473f868", null ],
    [ "autosave_on_exit", "d6/d4b/structGUISettings.html#a1757e4b8ca3b125457458f5cd6bf3ffa", null ],
    [ "autosave_on_network_disconnect", "d6/d4b/structGUISettings.html#a679f80f12d8e03e1989b37aa79624717", null ],
    [ "coloured_news_year", "d6/d4b/structGUISettings.html#ac00406cdec77670d750eb44779562150", null ],
    [ "console_backlog_length", "d6/d4b/structGUISettings.html#ae133cd309e0fc53db8c596f47098e367", null ],
    [ "console_backlog_timeout", "d6/d4b/structGUISettings.html#ad4a75a3676a8c045e1977dccebb28608", null ],
    [ "cycle_signal_types", "d6/d4b/structGUISettings.html#a63e9455fb34f1b508994b593452b5750", null ],
    [ "date_format_in_default_names", "d6/d4b/structGUISettings.html#a8626a8856fa1b11cc365821aff17790f", null ],
    [ "default_rail_type", "d6/d4b/structGUISettings.html#a6729ef97714ba6b5295e3864e1a4ee85", null ],
    [ "default_signal_type", "d6/d4b/structGUISettings.html#a7feb3f0526aaec124fcdf960ebb7c0b4", null ],
    [ "developer", "d6/d4b/structGUISettings.html#a08f934d1eb76baefecb84f949598c451", null ],
    [ "drag_signals_density", "d6/d4b/structGUISettings.html#a7e539529318f00374e2363c1bfbc9cff", null ],
    [ "drag_signals_fixed_distance", "d6/d4b/structGUISettings.html#ae77aba49ee246af20f17e6e052cf61da", null ],
    [ "enable_signal_gui", "d6/d4b/structGUISettings.html#ad8657e45f83032d9c1224e778f0594aa", null ],
    [ "errmsg_duration", "d6/d4b/structGUISettings.html#aae7ba8a64938e75825dbcf8c02974e37", null ],
    [ "expenses_layout", "d6/d4b/structGUISettings.html#a06f29bfa4f830f5c97ead1fada01dcb8", null ],
    [ "graph_line_thickness", "d6/d4b/structGUISettings.html#a2e0d88194a1b4797d60491e6964bd72a", null ],
    [ "hover_delay_ms", "d6/d4b/structGUISettings.html#a21f90aa923e99dac1cefab64ed67c65b", null ],
    [ "keep_all_autosave", "d6/d4b/structGUISettings.html#a63925d3627cd4ed21b980929c9c2395a", null ],
    [ "last_newgrf_count", "d6/d4b/structGUISettings.html#afbf528c6824373b976a87815375d49e5", null ],
    [ "link_terraform_toolbar", "d6/d4b/structGUISettings.html#afddd0226ca658d7b02fe9601c0827b4d", null ],
    [ "liveries", "d6/d4b/structGUISettings.html#a1c14ea815f79911d36f5cca2c683b021", null ],
    [ "loading_indicators", "d6/d4b/structGUISettings.html#aa9478057a4c116045d7e113e97a1b4c4", null ],
    [ "lost_vehicle_warn", "d6/d4b/structGUISettings.html#a0dd8600961bcf23ea2c1d117edca9558", null ],
    [ "max_num_autosaves", "d6/d4b/structGUISettings.html#a8af1718a1b1fc9cf932c68ea3494aefe", null ],
    [ "measure_tooltip", "d6/d4b/structGUISettings.html#a4412bd6c43ce96dd3379630bee8a950e", null ],
    [ "missing_strings_threshold", "d6/d4b/structGUISettings.html#ace5a5e01800552462bc1fef38dba8701", null ],
    [ "network_chat_box_height", "d6/d4b/structGUISettings.html#a962a0d37a0fbe0d01cd1af28115b6240", null ],
    [ "network_chat_box_width_pct", "d6/d4b/structGUISettings.html#ab12df18471fde742253676eb19a72c91", null ],
    [ "network_chat_timeout", "d6/d4b/structGUISettings.html#a335b5f12b0717178bf20bf12ea45e199", null ],
    [ "new_nonstop", "d6/d4b/structGUISettings.html#a407c886da49dcc2620b923d6b0a22267", null ],
    [ "newgrf_default_palette", "d6/d4b/structGUISettings.html#a5446aa3bb546a3a7e95a45c605089245", null ],
    [ "newgrf_developer_tools", "d6/d4b/structGUISettings.html#acd5ef5752ca38b54a08a3b44c8bbc8e2", null ],
    [ "newgrf_show_old_versions", "d6/d4b/structGUISettings.html#a09062f2103557e7d3fee67e819c4ece3", null ],
    [ "news_message_timeout", "d6/d4b/structGUISettings.html#aae3de842a821dca6d5c34252897f7735", null ],
    [ "order_review_system", "d6/d4b/structGUISettings.html#a2818d3c1565d14d8c0eec35ce0eeb23f", null ],
    [ "osk_activation", "d6/d4b/structGUISettings.html#a830eeb21c81227873bdd71df30058201", null ],
    [ "pause_on_newgame", "d6/d4b/structGUISettings.html#a75aeda92f381c00943cb79cb86b7ec9e", null ],
    [ "persistent_buildingtools", "d6/d4b/structGUISettings.html#a1e66f3809d6c65b31d39db76a1461789", null ],
    [ "population_in_label", "d6/d4b/structGUISettings.html#a36d9c9a82c0f6615474d358a87a3484e", null ],
    [ "prefer_teamchat", "d6/d4b/structGUISettings.html#aa66f8142bf06302b3236f1c21b3f0456", null ],
    [ "quick_goto", "d6/d4b/structGUISettings.html#a4d3627d051572a01964fadf497c78619", null ],
    [ "right_mouse_btn_emulation", "d6/d4b/structGUISettings.html#afcc4454d53ecaf68282983c8ebd2f25e", null ],
    [ "right_mouse_wnd_close", "d6/d4b/structGUISettings.html#a0d8f9dadd3d93c7eb61c027bb3fdf6c7", null ],
    [ "scenario_developer", "d6/d4b/structGUISettings.html#abbb77d6f5fc20d08cda75ebaf565c30d", null ],
    [ "scroll_mode", "d6/d4b/structGUISettings.html#a12e65e1884e37dc64e9e5a0c4f55513e", null ],
    [ "scrollwheel_multiplier", "d6/d4b/structGUISettings.html#afd9063dd9c6ca1b76e07dd58ef492326", null ],
    [ "scrollwheel_scrolling", "d6/d4b/structGUISettings.html#adb6733da730fa602ca7c298a0f2768e6", null ],
    [ "semaphore_build_before", "d6/d4b/structGUISettings.html#a237fb4a8bd2e7c929860a401e205323a", null ],
    [ "settings_restriction_mode", "d6/d4b/structGUISettings.html#a46580e3efdd7e19fc4d11becc535595e", null ],
    [ "sg_full_load_any", "d6/d4b/structGUISettings.html#a9438bcb839b52ae803f4a135f8003856", null ],
    [ "sg_new_nonstop", "d6/d4b/structGUISettings.html#a4243b60122d03cc0c746925c95b846ef", null ],
    [ "show_date_in_logs", "d6/d4b/structGUISettings.html#a02682a29aff6444be76befea9583d998", null ],
    [ "show_finances", "d6/d4b/structGUISettings.html#a46067f7629e679ed7860dbd4100c01d0", null ],
    [ "show_newgrf_name", "d6/d4b/structGUISettings.html#a0c4b703b90f65c5312ec49a8ac395a98", null ],
    [ "show_track_reservation", "d6/d4b/structGUISettings.html#ad3f6a7e911574bf31bd0bc69774d8c05", null ],
    [ "smallmap_land_colour", "d6/d4b/structGUISettings.html#a5fcc20981430a95d8211f451d788d850", null ],
    [ "smooth_scroll", "d6/d4b/structGUISettings.html#acc7b711572a38f36fdc255ee58101b2b", null ],
    [ "starting_colour", "d6/d4b/structGUISettings.html#a684c835b001038a59a98310dd2dbe02c", null ],
    [ "station_dragdrop", "d6/d4b/structGUISettings.html#a3539ae01ad6ab70eda52032b4de0a377", null ],
    [ "station_gui_group_order", "d6/d4b/structGUISettings.html#ae3f7e6dfd4109686411950a2fc9330a4", null ],
    [ "station_gui_sort_by", "d6/d4b/structGUISettings.html#a03635c4b14e6c2704e03538c883177a6", null ],
    [ "station_gui_sort_order", "d6/d4b/structGUISettings.html#a6ee3e60730b312f5f101221c7a3b3cd3", null ],
    [ "station_numtracks", "d6/d4b/structGUISettings.html#a129fbfa9e2899e2983507b20e754f987", null ],
    [ "station_platlength", "d6/d4b/structGUISettings.html#abb0190f461e1386ea6e640724b3824c0", null ],
    [ "station_show_coverage", "d6/d4b/structGUISettings.html#a8d95da504feb34858820f8d77f434ca8", null ],
    [ "statusbar_pos", "d6/d4b/structGUISettings.html#a1e8ef64db05bd4583df9ddcc3d4cd7e2", null ],
    [ "stop_location", "d6/d4b/structGUISettings.html#a2e182ef230ba6da2cd36120d1d740ad6", null ],
    [ "threaded_saves", "d6/d4b/structGUISettings.html#aecb8c40b18ab5796a51fb51ed5e7fe9f", null ],
    [ "timetable_arrival_departure", "d6/d4b/structGUISettings.html#abe3768b96d2684d361da909b87321c2d", null ],
    [ "timetable_in_ticks", "d6/d4b/structGUISettings.html#a671c585d6d0b62570d204fbe1fdad191", null ],
    [ "toolbar_pos", "d6/d4b/structGUISettings.html#aad97d9b590b61269c2c3364a48db37b9", null ],
    [ "vehicle_income_warn", "d6/d4b/structGUISettings.html#a92f6e672b23f6cb9c09cf82f2a658a43", null ],
    [ "window_snap_radius", "d6/d4b/structGUISettings.html#a40c492f7f2a23d39e4dd0a610c731e8a", null ],
    [ "window_soft_limit", "d6/d4b/structGUISettings.html#a7285321bd08a820bd3cd014636d0e83c", null ],
    [ "zoom_max", "d6/d4b/structGUISettings.html#ad11059d564af417f89dcb170bfb9187b", null ],
    [ "zoom_min", "d6/d4b/structGUISettings.html#a4c02707b87f2dedce08193d9ab6fb525", null ]
];
